@@ -48,8 +48,8 @@ function(u, v=NULL, cop=NULL, parafn=function(k) return(k),
        control$fnscale <- -1
        if(length(init.para) == 1) {
           warning("init.para is length one, need to use 1D 'Brent' method\n",
-                  " but then but interval **will require** specification,\n",
-                  " proceeding anyway with init.para and optim(),\n",
+                  " but then the interval **will require** specification,\n",
+                  " proceeding anyway with init.para and optim() call,\n",
                   " other warning message will be triggered by optim(),\n",
                   " suggest calling > mleCOP(..., interval=c(N,M), ...)")
        }
